@@ -7,7 +7,7 @@ use Scalar::Util 'looks_like_number';
 use List::Util   qw< min max uniq>;
 use version;
 
-our $VERSION = '0.000004';
+our $VERSION = '0.000005';
 
 # Default naming scheme for refactoring...
 my $DEFAULT_SUB_NAME          = '__REFACTORED_SUB__';
@@ -1965,7 +1965,7 @@ Code::ART - Analyze/Rename/Track Perl source code
 
 =head1 VERSION
 
-This document describes Code::ART version 0.000004
+This document describes Code::ART version 0.000005
 
 
 =head1 SYNOPSIS
@@ -2454,14 +2454,16 @@ B<I<WARNING>>: In some environments, C<CTRL-S> will suspend terminal
 interactions. If your terminal locks up when you use this mapping,
 hit C<CTRL-Q> to restart terminal interactions. In this case, 
 you will need to either change the behaviour of C<CTRL-S> in
-your terminal (for example: L<https://coderwall.com/p/ltiqsq/disable-ctrl-s-and-ctrl-q-on-terminal>),
+your terminal (for example:
+L<https://coderwall.com/p/ltiqsq/disable-ctrl-s-and-ctrl-q-on-terminal>,
+or L<https://stackoverflow.com/questions/3446320/in-vim-how-to-map-save-to-ctrl-s>),
 or else change this mapping to something else.>
 
 =item gd
 
 Jump to the declaration of the variable under the cursor.
 
-=item *
+=item E<0x2a>
 
 Jump to the next usage of the variable under the cursor.
 
@@ -2471,6 +2473,10 @@ The following Visual mode mappings are also available:
 
 =over
 
+=item <CTRL-M>
+
+Match all instances of the variable under the cursor.
+
 =item <CTRL-H>
 
 Hoist all instances of the visually selected code into a lexical variable.
@@ -2479,7 +2485,7 @@ Hoist all instances of the visually selected code into a lexical variable.
 
 Hoist all instances of the visually selected code into a lexical closure.
 
-=item <CTRL-S>
+=item <CTRL-R>
 
 Refactor all instances of the visually selected code into a parameterized subroutine.
 
@@ -2487,7 +2493,7 @@ Refactor all instances of the visually selected code into a parameterized subrou
 
 =item <CTRL-C><CTRL-C>
 
-=item <CTRL-S><CTRL-S>
+=item <CTRL-R><CTRL-R>
 
 Same as the single-control-character versions above, but these only refactor
 the code actually selected, rather than every equivalent instance throughout
@@ -2569,6 +2575,8 @@ marker?
 
 API errors are signalled by throwing an exception:
 
+=over
+
 =item C<< "%s argument of %s must be a %s" >>
 
 You called the specified subroutine with the wrong kind of argument.
@@ -2584,8 +2592,6 @@ Did you mean to put that argument in the subroutine's options hash instead?
 You passed an unexpected named argument via the specified subroutine's
 options hash. Did you misspell it, perhaps?
 
-=over
-
 =back
 
 
